CcsdsNdmError

Enum CcsdsNdmError 

#[non_exhaustive]
pub enum CcsdsNdmError { Io(Error), Format(Box<FormatError>), Validation(Box<ValidationError>), Epoch(EpochError), UnsupportedMessage(String), UnexpectedEof { context: String, }, }
The top-level error type for the CCSDS NDM library.

This enum wraps all possible errors that can occur during NDM parsing, validation, serialization, and I/O.

Example: Handling Parse Errors

use ccsds_ndm::messages::opm::Opm;
use ccsds_ndm::error::CcsdsNdmError;
use ccsds_ndm::kvn::parser::ParseKvn;

match Opm::from_kvn_str("CCSDS_OPM_VERS = 3.0\n...") {
    Ok(opm) => println!("Parsed: {:?}", opm),
    Err(e) => {
        if let Some(enum_err) = e.as_enum_error() {
            eprintln!("Invalid enum value '{}' for field '{}'", enum_err.value, enum_err.field);
        } else if let Some(validation_err) = e.as_validation_error() {
            eprintln!("Validation error: {}", validation_err);
        } else {
            eprintln!("Error: {}", e);
        }
    }
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Io(Error)

Errors occurring during I/O operations.



Format(Box<FormatError>)

Errors related to NDM format or syntax.



Validation(Box<ValidationError>)

Errors related to NDM data validation.



Epoch(EpochError)

Errors related to CCSDS Epochs.



UnsupportedMessage(String)

Error for unsupported CCSDS message types.



UnexpectedEof

Error when an unexpected end of input is reached.

Fields

context: String

Implementations

Source

impl CcsdsNdmError

pub fn as_kvn_parse_error(&self) -> Option<&KvnParseError>

Returns the inner KVN parse error if this is a FormatError::Kvn.

pub fn as_validation_error(&self) -> Option<&ValidationError>

Returns the inner validation error if this is a ValidationError.

pub fn as_format_error(&self) -> Option<&FormatError>

Returns the inner format error if this is a FormatError.

pub fn as_epoch_error(&self) -> Option<&EpochError>

Returns the inner epoch error if this is an EpochError.

pub fn as_io_error(&self) -> Option<&Error>

Returns the inner I/O error if this is an IoError.

pub fn as_xml_error(&self) -> Option<&Error>

Returns the inner XML error if this is an XmlError.

pub fn is_format_error(&self) -> bool

Returns true if this is any FormatError.

pub fn is_kvn_error(&self) -> bool

Returns true if this is a KVN FormatError.

pub fn is_validation_error(&self) -> bool

Returns true if this is a ValidationError.

pub fn is_io_error(&self) -> bool

Returns true if this is an I/O error.

pub fn is_epoch_error(&self) -> bool

Returns true if this is an epoch error.

pub fn as_enum_error(&self) -> Option<&EnumParseError>

Returns the inner EnumParseError if this is a FormatError::Enum.

pub fn as_parse_int_error(&self) -> Option<&ParseIntError>

Returns the inner ParseIntError if this is a FormatError::ParseInt.

pub fn as_parse_float_error(&self) -> Option<&ParseFloatError>

Returns the inner ParseFloatError if this is a FormatError::ParseFloat.

pub fn with_location(self, input: &str, offset: usize) -> Self

Populates location information for variants with line info.