#[non_exhaustive]pub enum FormatError {
Kvn(Box<KvnParseError>),
Xml(Error),
XmlDe(DeError),
XmlSer(SeError),
ParseFloat(ParseFloatError),
ParseInt(ParseIntError),
Enum(EnumParseError),
InvalidFormat(String),
XmlWithContext {
context: String,
source: DeError,
},
}Expand description
Errors related to the physical format or syntax of the NDM.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Kvn(Box<KvnParseError>)
Errors occurring during KVN parsing.
Xml(Error)
Errors occurring during XML parsing.
XmlDe(DeError)
Errors occurring during XML deserialization.
XmlSer(SeError)
Errors occurring during XML serialization.
ParseFloat(ParseFloatError)
Error when parsing a floating point number fails.
ParseInt(ParseIntError)
Error when parsing an integer number fails.
Enum(EnumParseError)
Error during enum parsing.
InvalidFormat(String)
Error when the format of a value or segment is invalid.
XmlWithContext
Errors occurring during XML deserialization with added context.