#[non_exhaustive]pub enum ValidationError {
MissingRequiredField {
block: Cow<'static, str>,
field: Cow<'static, str>,
line: Option<usize>,
},
Conflict {
fields: Vec<Cow<'static, str>>,
line: Option<usize>,
},
InvalidValue {
field: Cow<'static, str>,
value: String,
expected: Cow<'static, str>,
line: Option<usize>,
},
OutOfRange {
name: Cow<'static, str>,
value: String,
expected: Cow<'static, str>,
line: Option<usize>,
},
Generic {
message: Cow<'static, str>,
line: Option<usize>,
},
}Expand description
Errors related to the validation of NDM data against CCSDS rules.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingRequiredField
A required field was missing in the message.
Conflict
Two or more fields are in conflict.
InvalidValue
A value was provided that does not match the CCSDS specification.
OutOfRange
Specific validation error for values out of expected range.
Generic
General validation errors for cases not covered by specific variants.
Implementations
Sourceimpl ValidationError
impl ValidationError
Sourcepub fn missing_required(
block: impl Into<Cow<'static, str>>,
field: impl Into<Cow<'static, str>>,
) -> Self
pub fn missing_required( block: impl Into<Cow<'static, str>>, field: impl Into<Cow<'static, str>>, ) -> Self
Convenience constructor for a missing required field error.
Sourcepub fn invalid_value(
field: impl Into<Cow<'static, str>>,
value: impl Into<String>,
expected: impl Into<Cow<'static, str>>,
) -> Self
pub fn invalid_value( field: impl Into<Cow<'static, str>>, value: impl Into<String>, expected: impl Into<Cow<'static, str>>, ) -> Self
Convenience constructor for an invalid value error.
Sourcepub fn generic(message: impl Into<Cow<'static, str>>) -> Self
pub fn generic(message: impl Into<Cow<'static, str>>) -> Self
Convenience constructor for a generic validation error.