pub struct InternalParserError {
pub message: Cow<'static, str>,
pub contexts: ContextStack,
pub kind: Box<ParserErrorKind>,
}Expand description
A lightweight internal error type for winnow parsers.
Fields
message: Cow<'static, str>contexts: ContextStackkind: Box<ParserErrorKind>Trait Implementations
Sourceimpl AddContext<&str, StrContext> for InternalParserError
impl AddContext<&str, StrContext> for InternalParserError
Sourcefn add_context(
self,
_input: &&str,
_token: &<&str as Stream>::Checkpoint,
context: StrContext,
) -> Self
fn add_context( self, _input: &&str, _token: &<&str as Stream>::Checkpoint, context: StrContext, ) -> Self
Append to an existing error custom data Read more
Sourceimpl Clone for InternalParserError
impl Clone for InternalParserError
Sourcefn clone(&self) -> InternalParserError
fn clone(&self) -> InternalParserError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InternalParserError
impl Debug for InternalParserError
Sourceimpl FromExternalError<&str, CcsdsNdmError> for InternalParserError
impl FromExternalError<&str, CcsdsNdmError> for InternalParserError
Sourcefn from_external_error(input: &&str, e: CcsdsNdmError) -> Self
fn from_external_error(input: &&str, e: CcsdsNdmError) -> Self
Like
ParserError::from_input but also include an external error.Sourceimpl FromExternalError<&str, EnumParseError> for InternalParserError
impl FromExternalError<&str, EnumParseError> for InternalParserError
Sourcefn from_external_error(_input: &&str, e: EnumParseError) -> Self
fn from_external_error(_input: &&str, e: EnumParseError) -> Self
Like
ParserError::from_input but also include an external error.Sourceimpl FromExternalError<&str, EpochError> for InternalParserError
impl FromExternalError<&str, EpochError> for InternalParserError
Sourcefn from_external_error(_input: &&str, e: EpochError) -> Self
fn from_external_error(_input: &&str, e: EpochError) -> Self
Like
ParserError::from_input but also include an external error.Sourceimpl FromExternalError<&str, ParseFloatError> for InternalParserError
impl FromExternalError<&str, ParseFloatError> for InternalParserError
Sourcefn from_external_error(_input: &&str, e: ParseFloatError) -> Self
fn from_external_error(_input: &&str, e: ParseFloatError) -> Self
Like
ParserError::from_input but also include an external error.Sourceimpl FromExternalError<&str, ParseIntError> for InternalParserError
impl FromExternalError<&str, ParseIntError> for InternalParserError
Sourcefn from_external_error(_input: &&str, e: ParseIntError) -> Self
fn from_external_error(_input: &&str, e: ParseIntError) -> Self
Like
ParserError::from_input but also include an external error.Sourceimpl FromExternalError<&str, ValidationError> for InternalParserError
impl FromExternalError<&str, ValidationError> for InternalParserError
Sourcefn from_external_error(_input: &&str, e: ValidationError) -> Self
fn from_external_error(_input: &&str, e: ValidationError) -> Self
Like
ParserError::from_input but also include an external error.Sourceimpl ParserError<&str> for InternalParserError
impl ParserError<&str> for InternalParserError
Sourcefn from_input(_input: &&str) -> Self
fn from_input(_input: &&str) -> Self
Creates an error from the input position
Sourcefn into_inner(self) -> Result<Self::Inner, Self>
fn into_inner(self) -> Result<Self::Inner, Self>
Unwrap the mode, returning the underlying error, if present
Sourcefn assert(input: &I, _message: &'static str) -> Selfwhere
I: Debug,
fn assert(input: &I, _message: &'static str) -> Selfwhere
I: Debug,
Process a parser assertion
Sourcefn incomplete(input: &I, _needed: Needed) -> Self
fn incomplete(input: &I, _needed: Needed) -> Self
There was not enough data to determine the appropriate action Read more
Sourcefn append(self, _input: &I, _token_start: &<I as Stream>::Checkpoint) -> Self
fn append(self, _input: &I, _token_start: &<I as Stream>::Checkpoint) -> Self
Like
ParserError::from_input but merges it with the existing error. Read moreSourcefn is_backtrack(&self) -> bool
fn is_backtrack(&self) -> bool
Is backtracking and trying new parse branches allowed?
Sourceimpl PartialEq for InternalParserError
impl PartialEq for InternalParserError
impl StructuralPartialEq for InternalParserError